#
# spec file for package vkd3d
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define major 1

Name:           vkd3d
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  spirv-headers
BuildRequires:  xcb-util-keysyms-devel
BuildRequires:  pkgconfig(SPIRV-Tools)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-event)
BuildRequires:  pkgconfig(xcb-icccm)
URL:            https://winehq.org/
Summary:        Direct3D 12 to Vulkan translation library
License:        LGPL-2.1-or-later
Group:          System/X11/Utilities
Version:        1.8
Release:        1.2
Source0:        https://dl.winehq.org/vkd3d/source/vkd3d-%version.tar.xz
Source1:        https://dl.winehq.org/vkd3d/source/vkd3d-%version.tar.xz.sign
Source2:        %name.keyring
Source3:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%package -n libvkd3d%major
Summary:        Direct3D 12 to Vulkan translation library
Group:          System/Libraries

%package -n libvkd3d-utils%major
Summary:        Direct3D 12 to Vulkan translation library utilities
Group:          System/Libraries

%package -n libvkd3d-shader%major
Summary:        Direct3D 12 to Vulkan translation shader library
Group:          System/Libraries

%package devel
Summary:        Development headers for the Direct3D 12 to Vulkan translation library
Group:          Development/Libraries/X11
Requires:       libvkd3d%major = %version
Requires:       libvkd3d-utils%major = %version

%description
This is a Direct3D 12 to Vulkan translation library for use by e.g. Wine.

%description -n libvkd3d%major
This is a Direct3D 12 to Vulkan translation library for use by e.g. Wine.

%description -n libvkd3d-utils%major
This is a Direct3D 12 to Vulkan translation utilities library for use by e.g. Wine.

%description -n libvkd3d-shader%major
This is a Direct3D 12 to Vulkan shader library for use by e.g. Wine.

%description devel
This is a Direct3D 12 to Vulkan translation library for use by e.g. Wine.

These are its development libraries and headers.

%prep
%setup -q

%build
%configure \
	--disable-static \
	--disable-tests \
	--with-xcb \
	--with-spirv-tools

make %{?_smp_mflags}

%check
make check

%install
%make_install
rm %buildroot/%_libdir/*.la

%fdupes %buildroot/%_prefix

%files -n libvkd3d%{major}
%doc README ANNOUNCE AUTHORS
%license COPYING LICENSE
%defattr(-,root,root)
%_libdir/libvkd3d.so.%{major}*

%files -n libvkd3d-utils%{major}
%license COPYING LICENSE
%defattr(-,root,root)
%_libdir/libvkd3d-utils.so.%{major}*

%files -n libvkd3d-shader%{major}
%license COPYING LICENSE
%defattr(-,root,root)
%_libdir/libvkd3d-shader.so.%{major}*

%files devel
%defattr(-,root,root)
%license COPYING LICENSE
%doc AUTHORS README ANNOUNCE
%_includedir/*
%_libdir/*.so
%_libdir/pkgconfig/libvkd3d.pc
%_libdir/pkgconfig/libvkd3d-shader.pc
%_libdir/pkgconfig/libvkd3d-utils.pc
%_bindir/vkd3d-compiler

%post -n libvkd3d%{major} -p /sbin/ldconfig
%postun -n libvkd3d%{major} -p /sbin/ldconfig

%post -n libvkd3d-utils%{major} -p /sbin/ldconfig
%postun -n libvkd3d-utils%{major} -p /sbin/ldconfig

%post -n libvkd3d-shader%{major} -p /sbin/ldconfig
%postun -n libvkd3d-shader%{major} -p /sbin/ldconfig

%changelog
* Sun Aug  6 2023 Tobias Klausmann <tobias.klausmann@freenet.de>
- Update to version 1.8:
  - Performance improvements have been made to the code that handles descriptor
    updates. In some applications the improvement can be quite significant.
  - Host-visible descriptor heaps are persistently mapped on creation. Some
    applications access resource data from the CPU after calling Unmap(), and
    that's supposed to work in practice.
  - 1-dimensional texture unordered-access views and shader resource views are
    implemented.
  - Shader resource view, unordered access view, and constant buffer view root
    descriptors with NULL GPU addresses are supported.
  - Direct3D 12 descriptor heap destruction is delayed until all contained
    resources are destroyed.
  - libvkd3d-shader
  - New features for the HLSL source type:
  - Support for the ternary conditional operator "?:".
  - Support for "discard" statements.
  - Support for the "packoffset" keyword.
  - Support for semantics on array types.
  - Support for RWBuffer loads and stores.
  - Register allocation for arrays and structures of resources and samplers
    is implemented.
  - Support for the SV_IsFrontFace pixel shader system-value semantics.
  - Support for using constant expressions as array sizes and indices.
  - Support for dynamic selection of vector components.
  - Support for the following intrinsic functions: D3DCOLORtoUBYTE4(),
    any(), asfloat(), ddx(), ddy(), fmod(), log(), log2(), log10(), sign()
    and trunc().
  - The SampleBias(), SampleCmp(), SampleCmpLevelZero(), and SampleGrad()
    texture object methods are implemented.
  - Support for the case-insensitive variants of the "vector" and "matrix"
    data types.
  - Parser support for the "unroll" loop attribute. A warning is output for
    "unroll" without iteration count, and an error is output when an
    iteration count is specified. Actual unrolling is not implemented yet.
  - Parser support for RWStructuredBuffer resources.
  - Parser support for SamplerComparisonState objects. Note that outputting
    compiled effects is not supported yet, but parsing these allows shaders
    containing SamplerComparisonState state objects to be compiled.
  - More improvements to HLSL support for the Direct3D shader model 1/2/3
    profiles.
  - The section alignment of DXBC blobs produced by
    vkd3d_shader_serialize_dxbc() matches those produced by d3dcompiler more
    closely.
  - The "main" function for shaders produced by the SPIR-V target is always
    terminated, even when the source was a TPF shader without explicit "ret"
    instruction.
  - Relative addressing of shader input registers is supported by SPIR-V
    targets.
* Wed May 17 2023 Tobias Klausmann <tobias.klausmann@freenet.de>
- Update to version 1.7.1:
  - Release 1.7 has a bug that causes an internal mutex in its command queue
    implementation to be unlocked too early under certain usage patterns. This
    is known to further cause internal inconsistencies that manifest as program
    deadlocks for some programs. In release 1.7.1 the mutex is correctly kept
    locked until required.
  - Symbol D3D12CreateDevice is mistakenly not exported in release 1.7,
    breaking library clients that need it. The symbol is exported again in
    release 1.7.1.
* Sat Apr  1 2023 Tobias Klausmann <tobias.klausmann@freenet.de>
- Update to version 1.7:
  - Support for many more HLSL features and intrinsics.
  - Much improved support for the Direct3D shader model 1/2/3 HLSL profiles.
  - Public vkd3d-shader API for parsing and serialising DXBC blobs.
  - Miscellaneous bug fixes.
* Mon Dec 12 2022 Tobias Klausmann <tobias.klausmann@freenet.de>
- Update to version 1.6:
  - Initial support for HLSL compute shaders.
  - More support for HLSL features and intrinsics.
  - Miscellaneous bug fixes.
* Thu Oct 27 2022 Tobias Klausmann <tobias.klausmann@freenet.de>
- Update to version 1.5:
  - Support for various HLSL features and intrinsics.
  - Typed unordered access view loads of multicomponent formats.
  - Miscellaneous bug fixes.
- Packaging changes:
  - Disable test until they are fixed
* Thu Jun 23 2022 Marcus Meissner <meissner@suse.com>
- updated to 1.4
  - Many improvements to the HLSL compiler.
  - A new descriptor heap implementation using the VK_EXT_descriptor_indexing
    extension.
  - A new fence implementation using the VK_KHR_timeline_semaphore extension.
- updated to 1.3
  - Initial HLSL compilation support.
  - Shader model 5.1 descriptor array support.
  - Support for disassembling Direct3D shaders.
* Thu Sep 24 2020 Marcus Meissner <meissner@suse.com>
- added also shader library to baselibs.conf (bsc#1176894)
* Tue Sep 22 2020 Marcus Meissner <meissner@suse.com>
- updated to 1.2
  - Availability of libvkd3d-shader as a public library.
  - Support for tessellation shaders.
  - Version 1.1 root signatures.
  - Stream output support.
- added gpg signature and keyring.
* Sat May 30 2020 Marcus Meissner <meissner@suse.com>
- updated baselibs requires to allow better wine 32bit dependencies (bsc#1172310)
* Sun Oct  7 2018 meissner@suse.com
- updated to 1.1
  - Initial support for placed resources.
  - MoltenVK support.
  - Support for geometry shaders.
* Sun Jul 29 2018 jengelh@inai.de
- Fix RPM groups. Drop redundant ldconfig requires (they are
  implicit).
* Sun Jun 17 2018 meissner@suse.com
- ininital vkd3d library, Direct3D 12 to Vulkan translation library
